@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.0.4"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -70,7 +70,7 @@
 #define yychar          ppchar
 
 /* Copy the first part of user declarations.  */
-#line 1 "ppparse.y" /* yacc.c:339  */
+#line 1 "./ppparse.y" /* yacc.c:339  */
 
 /* Parser for gpasm preprocessor #v() evaluation
    Copyright (C) 2012 Borut Razem
@@ -95,17 +95,18 @@ Boston, MA 02111-1307, USA.  */
 #include "stdhdr.h"
 #include "libgputils.h"
 #include "gpasm.h"
+#include "gpmsg.h"
 #include "preprocess.h"
 
 int ppresult = 0;
 
 void
-pperror(const char *message)
+pperror(const char *Message)
 {
   /* do nothing */
 }
 
-#line 109 "ppparse.c" /* yacc.c:339  */
+#line 110 "ppparse.c" /* yacc.c:339  */
 
 # ifndef YY_NULLPTR
 #  if defined __cplusplus && 201103L <= __cplusplus
@@ -125,8 +126,8 @@ pperror(const char *message)
 
 /* In a future release of Bison, this section will be replaced
    by #include "y.tab.h".  */
-#ifndef YY_PP_Y_TAB_H_INCLUDED
-# define YY_PP_Y_TAB_H_INCLUDED
+#ifndef YY_PP_PPPARSE_H_INCLUDED
+# define YY_PP_PPPARSE_H_INCLUDED
 /* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 1
@@ -178,16 +179,18 @@ extern int ppdebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
-#line 37 "ppparse.y" /* yacc.c:355  */
+#line 38 "./ppparse.y" /* yacc.c:355  */
 
-  gpasmVal i;
-  char *s;
+  gpasmVal  i;
+  char     *s;
 
-#line 190 "ppparse.c" /* yacc.c:355  */
+#line 191 "ppparse.c" /* yacc.c:355  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -197,11 +200,11 @@ extern YYSTYPE pplval;
 
 int ppparse (void);
 
-#endif /* !YY_PP_Y_TAB_H_INCLUDED  */
+#endif /* !YY_PP_PPPARSE_H_INCLUDED  */
 
 /* Copy the second part of user declarations.  */
 
-#line 205 "ppparse.c" /* yacc.c:358  */
+#line 208 "ppparse.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -500,10 +503,10 @@ static const yytype_uint8 yytranslate[] =
   /* YYRLINE[YYN] -- Source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,    57,    57,    60,    65,    68,    84,    88,    92,    95,
-      98,   102,   105,   108,   111,   114,   117,   121,   124,   128,
-     131,   135,   138,   141,   145,   148,   151,   154,   157,   160,
-     163,   167
+       0,    58,    58,    61,    66,    69,   101,   105,   109,   112,
+     115,   119,   122,   125,   128,   131,   134,   138,   141,   145,
+     148,   152,   155,   158,   162,   165,   168,   171,   174,   177,
+     180,   184
 };
 #endif
 
@@ -1324,193 +1327,209 @@ yyreduce:
   switch (yyn)
     {
         case 3:
-#line 61 "ppparse.y" /* yacc.c:1646  */
+#line 62 "./ppparse.y" /* yacc.c:1646  */
     { ppresult = (yyvsp[0].i); }
-#line 1330 "ppparse.c" /* yacc.c:1646  */
+#line 1333 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 4:
-#line 66 "ppparse.y" /* yacc.c:1646  */
+#line 67 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[0].i); }
-#line 1336 "ppparse.c" /* yacc.c:1646  */
+#line 1339 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 5:
-#line 69 "ppparse.y" /* yacc.c:1646  */
+#line 70 "./ppparse.y" /* yacc.c:1646  */
     {
-    struct symbol *sym;
+    const symbol_t   *sym;
+    const variable_t *var;
+    char              buf[BUFSIZ];
 
-    if ((sym = get_symbol(state.stTop, (yyvsp[0].s))) != NULL) {
-      struct variable *var = get_symbol_annotation(sym);
+    if ((sym = gp_sym_get_symbol(state.stTop, (yyvsp[0].s))) != NULL) {
+      var = gp_sym_get_symbol_annotation(sym);
       assert(var != NULL);
+
+      if (FlagIsSet(var->flags, VATRR_HAS_NO_VALUE)) {
+        msg_has_no_value(NULL, (yyvsp[0].s));
+      }
+
       (yyval.i) = var->value;
     }
     else {
-      /* The default value is 0. */
+      if ((!state.mpasm_compatible) && (state.strict_level > 0)) {
+        snprintf(buf, sizeof(buf), "Symbol %s not assigned a value.", (yyvsp[0].s));
+
+        if (state.strict_level == 2) {
+          gpmsg_verror(GPE_USER, NULL, buf);
+        }
+        else {
+          gpmsg_vwarning(GPW_USER, NULL, buf);
+        }
+      }
       (yyval.i) = 0;
     }
   }
-#line 1354 "ppparse.c" /* yacc.c:1646  */
+#line 1373 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 6:
-#line 85 "ppparse.y" /* yacc.c:1646  */
+#line 102 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[-2].i) || (yyvsp[0].i)); }
-#line 1360 "ppparse.c" /* yacc.c:1646  */
+#line 1379 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 7:
-#line 89 "ppparse.y" /* yacc.c:1646  */
+#line 106 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[-2].i) && (yyvsp[0].i)); }
-#line 1366 "ppparse.c" /* yacc.c:1646  */
+#line 1385 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 8:
-#line 93 "ppparse.y" /* yacc.c:1646  */
+#line 110 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) & (yyvsp[0].i); }
-#line 1372 "ppparse.c" /* yacc.c:1646  */
+#line 1391 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 9:
-#line 96 "ppparse.y" /* yacc.c:1646  */
+#line 113 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) | (yyvsp[0].i); }
-#line 1378 "ppparse.c" /* yacc.c:1646  */
+#line 1397 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 10:
-#line 99 "ppparse.y" /* yacc.c:1646  */
+#line 116 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) ^ (yyvsp[0].i); }
-#line 1384 "ppparse.c" /* yacc.c:1646  */
+#line 1403 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 11:
-#line 103 "ppparse.y" /* yacc.c:1646  */
+#line 120 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) ^ (yyvsp[0].i); }
-#line 1390 "ppparse.c" /* yacc.c:1646  */
+#line 1409 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 12:
-#line 106 "ppparse.y" /* yacc.c:1646  */
+#line 123 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) ^ (yyvsp[0].i); }
-#line 1396 "ppparse.c" /* yacc.c:1646  */
+#line 1415 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 13:
-#line 109 "ppparse.y" /* yacc.c:1646  */
+#line 126 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[-2].i) == (yyvsp[0].i)); }
-#line 1402 "ppparse.c" /* yacc.c:1646  */
+#line 1421 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 14:
-#line 112 "ppparse.y" /* yacc.c:1646  */
+#line 129 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[-2].i) != (yyvsp[0].i)); }
-#line 1408 "ppparse.c" /* yacc.c:1646  */
+#line 1427 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 15:
-#line 115 "ppparse.y" /* yacc.c:1646  */
+#line 132 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[-2].i) >= (yyvsp[0].i)); }
-#line 1414 "ppparse.c" /* yacc.c:1646  */
+#line 1433 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 16:
-#line 118 "ppparse.y" /* yacc.c:1646  */
+#line 135 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[-2].i) <= (yyvsp[0].i)); }
-#line 1420 "ppparse.c" /* yacc.c:1646  */
+#line 1439 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 17:
-#line 122 "ppparse.y" /* yacc.c:1646  */
+#line 139 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) << (yyvsp[0].i); }
-#line 1426 "ppparse.c" /* yacc.c:1646  */
+#line 1445 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 18:
-#line 125 "ppparse.y" /* yacc.c:1646  */
+#line 142 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) >> (yyvsp[0].i); }
-#line 1432 "ppparse.c" /* yacc.c:1646  */
+#line 1451 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 19:
-#line 129 "ppparse.y" /* yacc.c:1646  */
+#line 146 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) + (yyvsp[0].i); }
-#line 1438 "ppparse.c" /* yacc.c:1646  */
+#line 1457 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 20:
-#line 132 "ppparse.y" /* yacc.c:1646  */
+#line 149 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) - (yyvsp[0].i); }
-#line 1444 "ppparse.c" /* yacc.c:1646  */
+#line 1463 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 21:
-#line 136 "ppparse.y" /* yacc.c:1646  */
+#line 153 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) * (yyvsp[0].i); }
-#line 1450 "ppparse.c" /* yacc.c:1646  */
+#line 1469 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 22:
-#line 139 "ppparse.y" /* yacc.c:1646  */
+#line 156 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) / (yyvsp[0].i); }
-#line 1456 "ppparse.c" /* yacc.c:1646  */
+#line 1475 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 23:
-#line 142 "ppparse.y" /* yacc.c:1646  */
+#line 159 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-2].i) / (yyvsp[0].i); }
-#line 1462 "ppparse.c" /* yacc.c:1646  */
+#line 1481 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 24:
-#line 146 "ppparse.y" /* yacc.c:1646  */
+#line 163 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[0].i) >> 16) & 0xff; }
-#line 1468 "ppparse.c" /* yacc.c:1646  */
+#line 1487 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 25:
-#line 149 "ppparse.y" /* yacc.c:1646  */
+#line 166 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ((yyvsp[0].i) >> 8) & 0xff; }
-#line 1474 "ppparse.c" /* yacc.c:1646  */
+#line 1493 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 26:
-#line 152 "ppparse.y" /* yacc.c:1646  */
+#line 169 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[0].i) & 0xff; }
-#line 1480 "ppparse.c" /* yacc.c:1646  */
+#line 1499 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 27:
-#line 155 "ppparse.y" /* yacc.c:1646  */
+#line 172 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = -(yyvsp[0].i); }
-#line 1486 "ppparse.c" /* yacc.c:1646  */
+#line 1505 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 28:
-#line 158 "ppparse.y" /* yacc.c:1646  */
+#line 175 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = !(yyvsp[0].i); }
-#line 1492 "ppparse.c" /* yacc.c:1646  */
+#line 1511 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 29:
-#line 161 "ppparse.y" /* yacc.c:1646  */
+#line 178 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = ~(yyvsp[0].i); }
-#line 1498 "ppparse.c" /* yacc.c:1646  */
+#line 1517 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 30:
-#line 164 "ppparse.y" /* yacc.c:1646  */
+#line 181 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[0].i); }
-#line 1504 "ppparse.c" /* yacc.c:1646  */
+#line 1523 "ppparse.c" /* yacc.c:1646  */
     break;
 
   case 31:
-#line 168 "ppparse.y" /* yacc.c:1646  */
+#line 185 "./ppparse.y" /* yacc.c:1646  */
     { (yyval.i) = (yyvsp[-1].i); }
-#line 1510 "ppparse.c" /* yacc.c:1646  */
+#line 1529 "ppparse.c" /* yacc.c:1646  */
     break;
 
 
-#line 1514 "ppparse.c" /* yacc.c:1646  */
+#line 1533 "ppparse.c" /* yacc.c:1646  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1738,5 +1757,5 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 170 "ppparse.y" /* yacc.c:1906  */
+#line 187 "./ppparse.y" /* yacc.c:1906  */
 
