@@ -1,19 +1,21 @@
 /* Displays contents of ".COD" files
    Copyright (C) 2001, 2002, 2003, 2004, 2005
    Scott Dattalo
+   Copyright (C) 2012 Borut Razem
+   Copyright (C) 2016 Molnar Karoly
 
 This file is part of gputils.
- 
+
 gputils is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.
- 
+
 gputils is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
- 
+
 You should have received a copy of the GNU General Public License
 along with gputils; see the file COPYING.  If not, write to
 the Free Software Foundation, 59 Temple Place - Suite 330,
@@ -24,8 +26,7 @@ Boston, MA 02111-1307, USA.  */
 
 #include "stdhdr.h"
 
-void directory_block(void);
-void read_block(char * block, int block_number);
-void read_directory(void);
+extern void read_block(FILE *Code_file, uint8_t *Block, unsigned int Block_number);
+extern DirBlockInfo *read_directory(FILE *Code_file);
 
 #endif
