@@ -23,15 +23,16 @@ Boston, MA 02111-1307, USA.  */
 #define __GPMESSAGE_H__
 
 extern gp_boolean gp_quiet;
+extern gp_boolean gp_message_disable;
 extern gp_boolean gp_debug_disable;
 
 extern int gp_num_errors;
 extern int gp_num_warnings;
 extern int gp_num_messages;
 
-void gp_error(const char *format, ...);
-void gp_warning(const char *format, ...);
-void gp_message(const char *format, ...);
-void gp_debug(const char *format, ...);
+extern void gp_error(const char *Format, ...);
+extern void gp_warning(const char *Format, ...);
+extern void gp_message(const char *Format, ...);
+extern void gp_debug(const char *Format, ...);
 
 #endif
