@@ -22,81 +22,98 @@ Boston, MA 02111-1307, USA.  */
 #include "stdhdr.h"
 #include "libgputils.h"
 
-#define LINESIZ 520
+#define LINESIZ         520
 
-static char linebuf[LINESIZ];
-static char *linept;
-static int checksum;
-static FILE *infile;
+static char     linebuf[LINESIZ];
+static char    *linept;
+static uint8_t  checksum;
+static FILE    *infile;
+
+/*------------------------------------------------------------------------------------------------*/
 
 /* Converts a single ASCII character into a number. */
-static unsigned int
-a2n(unsigned char character)
-{
-  unsigned int number;
 
-  if (character <= '9') {
-    number = character - '0';
-  } else {
+static uint8_t
+_a2n(uint8_t Character)
+{
+  uint8_t number;
+
+  if (Character <= '9') {
+    number = Character - '0';
+  }
+  else {
     /* Convert lower case to upper. */
-    character &= ~('a' - 'A');
-    number = character - ('A' - 10);
+    Character &= ~('a' - 'A');
+    number = Character - ('A' - 10);
   } 
   return number;
 }
 
-static unsigned int
-readbyte(void)
+/*------------------------------------------------------------------------------------------------*/
+
+static uint8_t
+_readbyte(void)
 {
-  unsigned int number;
+  uint8_t number;
 
   linept++;
-  number = a2n(*linept) << 4;
+  number  = _a2n(*linept) << 4;
   linept++;
-  number |= a2n(*linept);
+  number |= _a2n(*linept);
+
   checksum += number;
   return number;
 } 
 
-static unsigned int
-readword(void)
-{
-  unsigned int number;
+/*------------------------------------------------------------------------------------------------*/
 
-  number = readbyte();  
-  number = (readbyte() << 8) | number;
+static uint16_t
+_readword(void)
+{
+  uint16_t number;
+
+  number  = (uint16_t)_readbyte();  
+  number |= (uint16_t)_readbyte() << 8;
   return number; 
 }
 
-static unsigned int
-swapword(unsigned int input)
-{
-  unsigned int number;
+/*------------------------------------------------------------------------------------------------*/
 
-  number = ((input & 0xFF) << 8) | ((input & 0xFF00) >> 8);
+static uint16_t
+_swapword(uint16_t Input)
+{
+  uint16_t number;
+
+  number = ((Input & 0xFF) << 8) | ((Input & 0xFF00) >> 8);
   return number;
 }
 
-struct hex_data *
-readhex(const char *filename, MemBlock *m)
-{
-  struct hex_data *info = GP_Malloc(sizeof(*info));
-  unsigned int length, address, type, data;
-  int i;
-  unsigned int page = 0;
+/*------------------------------------------------------------------------------------------------*/
 
+hex_data_t *
+gp_readhex(const char *File_name, MemBlock_t *M)
+{
+  hex_data_t   *info;
+  unsigned int  length;
+  unsigned int  address;
+  unsigned int  type;
+  uint8_t       byte;
+  unsigned int  i;
+  unsigned int  page;
+
+  info = GP_Malloc(sizeof(*info));
   info->hex_format = INHX8M;
-  info->size = 0;
-  info->error = 0;
+  info->size       = 0;
+  info->error      = false;
 
   /* Open the input file. */
-  if ((infile = fopen(filename, "rt")) == NULL) {
-    perror(filename);
+  if ((infile = fopen(File_name, "rt")) == NULL) {
+    perror(File_name);
     exit(1);
   }
     
   /* Go to the beginning of the file. */
-  fseek(infile, 0L, 0);
+  fseek(infile, 0L, SEEK_SET);
 
   /* Set the line pointer to the beginning of the line buffer. */
   linept = linebuf;
@@ -110,45 +127,45 @@ readhex(const char *filename, MemBlock *m)
     checksum = 0;
 
     /* Fetch the number of bytes. */
-    length = readbyte();
+    length = _readbyte();
     if (length == 0) {
       fclose(infile);
       return info;
     }
 
     /* Fetch the address. */
-    address = readword();
-    address = swapword(address);
+    address = _swapword(_readword());
 
     if (info->hex_format == INHX16) {
       address *= 2;
-      length *= 2;
+      length  *= 2;
     }
 
     /* Read the type of record. */
-    type = readbyte();
+    type = _readbyte();
 
-    if (type == 4) {
+    if (type == IHEX_RECTYPE_EXT_LIN_ADDR) {
       if (info->hex_format == INHX16) {
         printf("\nHex Format Error\n");
         fclose(infile);
-        info->error = 1;
+        info->error = true;
         return info;      
       }
 
       /* INHX32 segment line. */
-      page = ((readbyte() << 8) + readbyte()) << 16;
+      page = ((_readbyte() << 8) + _readbyte()) << 16;
       info->hex_format = INHX32;
-    } else {
+    }
+    else {
       /* Read the data (skipping last byte if at odd address). */
       for (i = 0; i < length; ++i) {
-	data = readbyte();
+	byte = _readbyte();
 
 	if (info->hex_format == INHX16) {
-	  b_memory_put(m, page | ((address + i) ^ 1), data, filename, NULL);
+	  gp_mem_b_put(M, page | ((address + i) ^ 1), byte, File_name, NULL);
 	}
 	else {
-	  b_memory_put(m, page | (address + i),       data, filename, NULL);
+	  gp_mem_b_put(M, page | (address + i),       byte, File_name, NULL);
 	}
       }
 
@@ -156,21 +173,22 @@ readhex(const char *filename, MemBlock *m)
     }
 
     /* Read the checksum, data is thrown away. */
-    data = readbyte();
+    _readbyte();
 
-    if ((checksum & 0xFF) != 0) { 
+    if (checksum != 0) { 
       if (info->hex_format == INHX8M) {
         /*  First attempt at INHX8M failed, try INHX16. */
-        fseek(infile, 0L, 0);	  
+        fseek(infile, 0L, SEEK_SET);	  
         info->hex_format = INHX16;
-        info->size = 0;
+        info->size       = 0;
         /* Data in i_memory is trash. */
-        i_memory_free(m);
-        m = i_memory_create();
-      } else {
+        gp_mem_i_free(M);
+        M = gp_mem_i_create();
+      }
+      else {
         printf("\nChecksum Error\n");
         fclose(infile);
-        info->error = 1;
+        info->error = true;
         return info;
       }
     }
